@@ -1,11 +1,16 @@
-import logging
-import traceback
+import importlib
 from decimal import Decimal
 
-from sqlalchemy.orm import sessionmaker, scoped_session
-from sqlalchemy.util.compat import contextmanager
 from tornado.options import options
 
+sqlalchemy_orm = None
+sqlalchemy_util_compat = None
+try:
+    sqlalchemy_orm = importlib.import_module("sqlalchemy.orm")
+    sqlalchemy_util_compat = importlib.import_module("sqlalchemy.util.compat")
+except ImportError as e:
+    raise Exception(f"sqlalchemy is not exist,run:pip install sqlalchemy==1.4.36")
+
 
 class SqlAlchemyHelper:
     def __init__(self, pool):
@@ -18,9 +23,9 @@ class SqlAlchemyHelper:
         else:
             self.pool = pool
 
-    @contextmanager
+    @sqlalchemy_util_compat.contextmanager
     def make_session(self, **kwargs):
-        db_session = scoped_session(sessionmaker(bind=self.pool, **kwargs))
+        db_session = sqlalchemy_orm.scoped_session(sqlalchemy_orm.sessionmaker(bind=self.pool, **kwargs))
         session = db_session()
         yield session
         session.commit()
