@@ -1,8 +1,12 @@
 import base64
+import importlib
 
-from Crypto.PublicKey import RSA as Rsa
-from Crypto.Cipher import PKCS1_v1_5 as Cipher_pkcs1_v1_5
-from Crypto import Random
+try:
+    Rsa = importlib.import_module("Cryptodome.PublicKey.RSA")
+    Cipher_pkcs1_v1_5 = importlib.import_module("Cryptodome.Cipher.PKCS1_v1_5")
+    Random = importlib.import_module("Cryptodome.Random")
+except ImportError as e:
+    raise Exception(f"pycryptodomex is not exist,run:pip install pycryptodomex==3.17")
 
 
 class RSA:
@@ -22,15 +26,15 @@ class RSA:
         return key
 
     @staticmethod
-    def encrypt(string: str, public_key: str, encoding='utf-8'):
+    def encrypt(text: str, public_key: str, encoding='utf-8'):
         rsa_key = Rsa.importKey(public_key)
         cipher = Cipher_pkcs1_v1_5.new(rsa_key)
-        encrypt_string = base64.b64encode(cipher.encrypt(string.encode(encoding))).decode(encoding)
+        encrypt_string = base64.b64encode(cipher.encrypt(text.encode(encoding))).decode(encoding)
         return encrypt_string
 
     @staticmethod
-    def decrypt(string: str, private_key: str, encoding='utf-8'):
+    def decrypt(text: str, private_key: str, encoding='utf-8'):
         rsa_key = Rsa.importKey(private_key)
         cipher = Cipher_pkcs1_v1_5.new(rsa_key)
-        decrypt_string = cipher.decrypt(base64.b64decode(string.encode(encoding)), "解密失败").decode(encoding)
+        decrypt_string = cipher.decrypt(base64.b64decode(text.encode(encoding)), "解密失败").decode(encoding)
         return decrypt_string
